Learn R Programming

SESraster (version 0.7.0)

.lyr.sample: Internal function to resample a vector according to the observed frequency

Description

Internal function to resample a vector according to the observed frequency

Usage

.lyr.sample(x, fr)

Value

vector

Arguments

x

numeric. A vector containing values to resampling.

fr

data.frame A data.frame with 3 columns (layer, value, count).

Author

Neander Marcel Heming