Learn R Programming

SESraster (version 0.7.0)

.str.sample: Vectorized structured sample

Description

Vectorized structured sample

Usage

.str.sample(x, sp, resu, fr_prob)

Value

vector of sampled sp elements

Arguments

x

vector containing sample size (i.e. richness) in the first element and probabilities on the remaining

sp

elements to be sampled

resu

vector of results, must be the same length of sp

fr_prob

Frequency or probability of each sp element. This will be multiplied by the probability vector

Author

Neander Marcel Heming